@@ -87,11 +87,6 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	KeyScrollingDelayOption(ZLCategoryKey::CONFIG, "Scrollings", "Delay", 0, 2000, 100),
 	LinesToScrollOption(ZLCategoryKey::CONFIG, "SmallScrolling", "LinesToScroll", 1, 20, 1),
 	LinesToKeepOption(ZLCategoryKey::CONFIG, "LargeScrolling", "LinesToKeepOption", 0, 20, 0),
-	EnableTapScrollingOption(ZLCategoryKey::CONFIG, "TapScrolling", "Enabled", true),
-	TapScrollingOnFingerOnlyOption(ZLCategoryKey::CONFIG, "TapScrolling", "FingerOnly", true),
-	TapScrollingOnDragOnlyOption(ZLCategoryKey::CONFIG, "TapScrolling", "DragOnly", true),
-	VariableDragOption(ZLCategoryKey::CONFIG, "TapScrolling", "VariableDrag", false),
-	VariableDragLengthOption(ZLCategoryKey::CONFIG, "TapScrolling", "VariableDragLength", 0, 800, 100),
 	UseSeparateBindingsOption(ZLCategoryKey::CONFIG, "KeysOptions", "UseSeparateBindings", false),
 	EnableSingleClickDictionaryOption(ZLCategoryKey::CONFIG, "Dictionary", "SingleClick", false),
 	myBindings0(new ZLKeyBindings("Keys")),
@@ -114,7 +109,7 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	myPreviousMode = BOOK_TEXT_MODE;
 	setMode(BOOK_TEXT_MODE);
 
-	addAction(ActionCode::SHOW_READING, new UndoAction(FBReader::ALL_MODES & ~FBReader::BOOK_TEXT_MODE));
+	addAction(ActionCode::SHOW_READING, new BookViewOption());
 	addAction(ActionCode::SHOW_LIBRARY, new SetModeAction(FBReader::LIBRARY_MODE, FBReader::BOOK_TEXT_MODE | FBReader::CONTENTS_MODE));
 	addAction(ActionCode::SHOW_NETWORK_LIBRARY, new ShowNetworkLibraryAction());
 	addAction(ActionCode::SEARCH_ON_NETWORK, new SimpleSearchOnNetworkAction());
@@ -158,10 +153,9 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	addAction(ActionCode::CLEAR_SELECTION, new ClearSelectionAction());
 	addAction(ActionCode::GOTO_PAGE_NUMBER, new GotoPageNumberAction(std::string()));
 	addAction(ActionCode::GOTO_PAGE_NUMBER_WITH_PARAMETER, new GotoPageNumberAction(PageIndexParameter));
-	shared_ptr<Action> booksOrderAction = new BooksOrderAction();
-	addAction(ActionCode::ORGANIZE_BOOKS_BY_AUTHOR, booksOrderAction);
-	addAction(ActionCode::ORGANIZE_BOOKS_BY_TAG, booksOrderAction);
-	addAction(ActionCode::ORGANIZE_BOOKS_BY_NAME, booksOrderAction);
+	addAction(ActionCode::ORGANIZE_BOOKS_BY_AUTHOR, new BooksOrderAction(ActionCode::ORGANIZE_BOOKS_BY_AUTHOR));
+	addAction(ActionCode::ORGANIZE_BOOKS_BY_TAG, new BooksOrderAction(ActionCode::ORGANIZE_BOOKS_BY_TAG));
+	addAction(ActionCode::ORGANIZE_BOOKS_BY_NAME, new BooksOrderAction(ActionCode::ORGANIZE_BOOKS_BY_NAME));
 	addAction(ActionCode::FILTER_LIBRARY, new FilterLibraryAction());
 
 	myOpenFileHandler = new OpenFileHandler();
@@ -406,6 +400,14 @@ void FBReader::showLibraryView() {
 	}
 }
 
+void FBReader::showLibraryView(const std::string &actionId) {
+	if (ZLStringOption(ZLCategoryKey::LOOK_AND_FEEL, "ToggleButtonGroup", "booksOrder", "").value() != actionId) {
+		setToolbarToggle(actionId);
+	}
+
+	showLibraryView();
+}
+
 void FBReader::setMode(ViewMode mode) {
 	if (mode == myMode) {
 		return;
@@ -420,7 +422,9 @@ void FBReader::setMode(ViewMode mode) {
 
 	switch (myMode) {
 		case BOOK_TEXT_MODE:
-			checkFullscreenSetup(true);
+			if (! EnablePopupMenuOption.value()) {
+				checkFullscreenSetup(true);
+			}
 			setHyperlinkCursor(false);
 			((ZLTextView&)*myBookTextView).forceScrollbarUpdate();
 			setView(myBookTextView);
@@ -434,7 +438,9 @@ void FBReader::setMode(ViewMode mode) {
 			break;
 		case LIBRARY_MODE:
 		{
-			checkFullscreenSetup(false);
+			if (! EnablePopupMenuOption.value()) {
+				checkFullscreenSetup(false);
+			}
 			shared_ptr<Book> currentBook = myModel->book();
 			((LibraryView&)*myLibraryByAuthorView).showBook(currentBook);
 			((LibraryView&)*myLibraryByTagView).showBook(currentBook);
