@@ -34,8 +34,15 @@
 
 static const std::string SEARCH_PARAMETER_ID = "networkSearchPattern";
 
+#if MAEMO_VERSION >= 4
+// In Maemo5, we only show Net Library in the Book Collection view
+#define NET_LIBRARY_VISIBILITY_MODE FBReader::LIBRARY_MODE
+#else
+// Normally, the Net Library is shown in the Book view
+#define NET_LIBRARY_VISIBILITY_MODE FBReader::BOOK_TEXT_MODE
+#endif
 
-ShowNetworkLibraryAction::ShowNetworkLibraryAction() : SetModeAction(FBReader::NETWORK_LIBRARY_MODE, FBReader::BOOK_TEXT_MODE) {
+ShowNetworkLibraryAction::ShowNetworkLibraryAction() : SetModeAction(FBReader::NETWORK_LIBRARY_MODE, NET_LIBRARY_VISIBILITY_MODE) {
 }
 
 bool ShowNetworkLibraryAction::isVisible() const {
